@@ -1,5 +1,6 @@
 """Imports the provider modules"""
 from .cloudflare import Cloudflare
 from .hurricaneElectric import HurricaneElectric
+from .strato import Strato
 
-__all__ = ["Cloudflare", "HurricaneElectric"]
+__all__ = ["Cloudflare", "HurricaneElectric", "Strato"]
